@@ -190,7 +190,6 @@
 #define COLOR_NONE             "#000000"
 #define COLOR_BKGD             "#FFFFFF"
 
-#define SOUND_MOVE ""
 #define SOUND_BELL "$"
 
 #define ICS_LOGON "ICS.ini"
@@ -220,7 +219,10 @@
 #define BUILT_IN_SOUND_NAMES {\
   "Beepbeep", "Ching", "Click", "Cymbal", "Ding", "Drip", \
   "Gong", "Laser", "Move", "Penalty", "Phone", "Pop", "Pop2", \
-  "Slap", "Squeak", "Swish", "Thud", "Whipcrack", NULL \
+  "Slap", "Squeak", "Swish", "Thud", "Whipcrack", \
+  "Alarm", "Challenge", "Channel", "Channel1", "Draw", "Kibitz", \
+  "Lose", "Request", "Seek", "Shout", "SShout", "Tell", "Unfinished", \
+  "Win", NULL \
 }
 
 #define ICS_TEXT_MENU_DEFAULT \
